#!/bin/sh

# c-raehs-funcs.sh

FILENAME=$1
shift

USAGE="Usage: $FILENAME [ -D macroname ]"

ERRFILE="${FILENAME}.err"

# ----------------------------------------------------------------------- #
# Validate command line options                                           #
# ----------------------------------------------------------------------- #

while getopts ":D:" ARG_STRING
do
    case $ARG_STRING in
    D)	MACRODEF=$OPTARG
	;;
    *)	echo $USAGE
	exit;;
    esac
done

if [ -n MACRODEF ]
then
    case $MACRODEF in
    SCORE) 
	SCORETYPE=
	EXTRAOPTS="-b .8"
	;;
    PVLC) 
	SCORETYPE="_vlc"
	EXTRAOPTS="-s 1 -c 3"
	;;
    PVL1) 
	SCORETYPE=_vl1
	EXTRAOPTS="-s 2 -c 3"
	;;
    PVL2) 
	SCORETYPE=_vl2
	EXTRAOPTS="-s 3 -c 3"
	;;
    PVLA) 
	SCORETYPE=_vla
	EXTRAOPTS="-s 4 -c 3"
	;;
    PBS) 
	SCORETYPE=_vcl
	EXTRAOPTS="-s 5 -c 3"
	;;
    PBC) 
	SCORETYPE=_bc
	EXTRAOPTS="-s 6 -c 3"
	;;
    *)  
	echo Macronames: SCORE, PVLC, PVL1, PVL2, PVLA, PBS, PBC
	exit;;
    esac
fi

# ----------------------------------------------------------------------- #
# Define functions                                                        #
# ----------------------------------------------------------------------- #

muppage() { 
    MUPOPTS=""
    PAGE=$2
    INFILE=${1}.mup 
    OUTFILE=${1}${SCORETYPE}p${PAGE}.ps
    if [ "${EXTRAOPTS}" ]; then MUPOPTS="${EXTRAOPTS} "; fi
    MUPOPTS="${MUPOPTS} -D $MACRODEF -o ${PAGE} ${INFILE} -f ${OUTFILE} -e ${ERRFILE}"
    mup ${MUPOPTS} > /dev/null 2>&1 
    if [ $? -gt 0 ] 
    then 
	if [ -s ${ERRFILE} ]
	then
	    cat ${ERRFILE}
	else
	    echo "mup ${MUPOPTS}"
	fi
	exit 
    fi
    rm -f ${ERRFILE} > /dev/null 2>&1 
}

epsipage() { 
    PAGE=$2
    INFILE=${1}${SCORETYPE}p${PAGE}.ps
    ps2epsi ${INFILE} > ${ERRFILE} 2>&1 
    if [ $? -gt 0 ]
    then
	cat ${ERRFILE}
	exit
    fi
    rm -f ${INFILE} > /dev/null 2>&1 
    rm -f ${ERRFILE} > /dev/null 2>&1 
}

mkps() { 
    dvips -tletter -e0 -O 4mm,0mm $1.dvi -o $1.ps > ${ERRFILE} 2>&1 
    if [ $? -gt 0 ]
    then
	cat ${ERRFILE}
	exit
    fi
    rm -f ${ERRFILE} > /dev/null 2>&1 
}

domovement() {
    i=1; maxp=$1
    while [ $i -le $maxp ]
    do
	muppage $2 $i || exit 1
	epsipage $2 $i || exit 1
	let i=$i+1
    done
}

tex2epsi() {
    tex $1 > ${ERRFILE} 2>&1 
    if [ $? -gt 0 ]
    then
	cat ${ERRFILE}
	exit
    fi
    dvips -E $1 -o ${1}.epsi > ${ERRFILE} 2>&1
    if [ $? -gt 0 ]
    then
	cat ${ERRFILE}
	exit
    fi
}

tex2epsipage() {
    PAGE=$2
    tex $1 > ${ERRFILE} 2>&1 
    if [ $? -gt 0 ]
    then
	cat ${ERRFILE}
	exit
    fi
    dvips -E -pp $2 $1 -o ${1}_p${2}.epsi > ${ERRFILE} 2>&1
    if [ $? -gt 0 ]
    then
	cat ${ERRFILE}
	exit
    fi
}

mup2epsi() {
    mup -F $1 > ${ERRFILE} 2>&1 
    if [ $? -gt 0 ]
    then
	cat ${ERRFILE}
	exit
    fi
    ps2epsi ${1}.ps > ${ERRFILE} 2>&1
    if [ $? -gt 0 ]
    then
	cat ${ERRFILE}
	exit
    fi
}

